searchData={"items":[{"type":"module","title":"BitConverter","doc":"Provides functions for encoding and decoding binaries, with support for both little-endian and big-endian systems.","ref":"BitConverter.html"},{"type":"module","title":"About endianness - BitConverter","doc":"The endianness system used in the conversion can be set in the function's options.\nEndian and endianness (or \"byte-order\") describe how computers  organize the bytes that make up numbers.\nBy far the most common ordering of multiple bytes in one   number is the little-endian, which is used on\nall Intel processors. Little-endian means storing bytes in order of least-to-most-significant\n(where the least significant byte takes the first or lowest address), comparable to a common European\nway of writing dates (e.g., 31 December 2050).\n\nNaturally, big-endian is the opposite order, comparable to an ISO date (2050-12-31). Big-endian is also\noften called \"network byte order\", because Internet standards usually require data to be stored big-endian,\nstarting at the standard UNIX socket level and going all the way up to standardized Web binary data\nstructures. Also, older Mac computers using 68000-series and PowerPC microprocessors formerly used  big-endian.\n\n(source: https://developer.mozilla.org/en-US/docs/Glossary/Endianness)","ref":"BitConverter.html#module-about-endianness"},{"type":"function","title":"BitConverter.decode_int16/2","doc":"Converts a binary representing a 16-bit signed integer into an integer.\nA 16-bit signed integer ranges from -32,768 to 32,767.\nRaises a `FunctionClauseError` if the binary doesn't have exactly 2 bytes.","ref":"BitConverter.html#decode_int16/2"},{"type":"function","title":"Parameters - BitConverter.decode_int16/2","doc":"- `binary`: A binary pattern that matches a 16-bit signed integer.\n\n  - `opts` (Keyword list, optional): Additional options.\n    - `:endianness` (atom): `:little` for little-endian or `:big` for big-endian. Defaults to `:little`.","ref":"BitConverter.html#decode_int16/2-parameters"},{"type":"function","title":"Examples - BitConverter.decode_int16/2","doc":"iex> BitConverter.decode_int16(<<0, 0>>)\n    0\n\n    iex> BitConverter.decode_int16(<<10, 0>>)\n    10\n\n    iex> BitConverter.decode_int16(<<0, 128>>)\n    -32_768\n\n    iex> BitConverter.decode_int16(<<255, 127>>)\n    32_767\n\n    iex> BitConverter.decode_int16(<<10, 0>>, endianess: :big)\n    2560\n\n    iex> BitConverter.decode_int16(<<0, 128>>, endianess: :big)\n    128\n\n    iex> BitConverter.decode_int16(<<255, 127>>, endianess: :big)\n    -129\n\n    iex> BitConverter.decode_int16(<<1, 0, 0>>)\n    ** (FunctionClauseError) no function clause matching in BitConverter.decode_int16/2","ref":"BitConverter.html#decode_int16/2-examples"},{"type":"function","title":"BitConverter.decode_int32/2","doc":"Converts a binary representing a 32-bit signed integer into an integer.\nA 32-bit signed integer ranges from -2,147,483,648 to 2,147,483,647.\nRaises a `FunctionClauseError` when the binary has more than 32 bits.","ref":"BitConverter.html#decode_int32/2"},{"type":"function","title":"Parameters - BitConverter.decode_int32/2","doc":"- `binary`: A binary pattern that matches a 32-bit signed integer.\n\n  - `opts` (Keyword list, optional): Additional options.\n    - `:endianness` (atom): `:little` for little-endian or `:big` for big-endian. Defaults to `:little`.","ref":"BitConverter.html#decode_int32/2-parameters"},{"type":"function","title":"Examples - BitConverter.decode_int32/2","doc":"iex> BitConverter.decode_int32(<<0, 0, 0, 0>>)\n    0\n\n    iex> BitConverter.decode_int32(<<10, 0, 0, 0>>)\n    10\n\n    iex> BitConverter.decode_int32(<<0, 0, 0, 128>>)\n    -2_147_483_648\n\n    iex> BitConverter.decode_int32(<<255, 255, 255, 127>>)\n    2_147_483_647\n\n    iex> BitConverter.decode_int32(<<1, 0, 0, 0>>, endianess: :big)\n    16_777_216\n\n    iex> BitConverter.decode_int32(<<10, 0, 0, 0>>, endianess: :big)\n    167_772_160\n\n    iex> BitConverter.decode_int32(<<255, 255, 255, 127>>, endianess: :big)\n    -129\n\n    iex> BitConverter.decode_int32(<<1, 0, 0, 0, 0>>)\n    ** (FunctionClauseError) no function clause matching in BitConverter.decode_int32/2","ref":"BitConverter.html#decode_int32/2-examples"},{"type":"function","title":"BitConverter.decode_uint16/2","doc":"Converts a binary representing a 16-bit unsigned integer into an integer.\nA 16-bit unsigned integer ranges from 0 to 65,535.\nRaises a `FunctionClauseError` if the binary doesn't have exactly 2 bytes.","ref":"BitConverter.html#decode_uint16/2"},{"type":"function","title":"Parameters - BitConverter.decode_uint16/2","doc":"- `binary`: A binary pattern that matches a 16-bit unsigned integer.\n\n  - `opts` (Keyword list, optional): Additional options.\n    - `:endianness` (atom): `:little` for little-endian or `:big` for big-endian. Defaults to `:little`.","ref":"BitConverter.html#decode_uint16/2-parameters"},{"type":"function","title":"Examples - BitConverter.decode_uint16/2","doc":"iex> BitConverter.decode_uint16(<<0, 0>>)\n    0\n\n    iex> BitConverter.decode_uint16(<<1, 0>>)\n    1\n\n    iex> BitConverter.decode_uint16(<<10, 0>>)\n    10\n\n    iex> BitConverter.decode_uint16(<<255, 255>>)\n    65535\n\n    iex> BitConverter.decode_uint16(<<1, 0>>, endianess: :big)\n    256\n\n    iex> BitConverter.decode_uint16(<<10, 0>>, endianess: :big)\n    2560\n\n    iex> BitConverter.decode_uint16(<<255, 255>>, endianess: :big)\n    65535\n\n    iex> BitConverter.decode_uint16(<<1, 0, 0>>)\n    ** (FunctionClauseError) no function clause matching in BitConverter.decode_uint16/2","ref":"BitConverter.html#decode_uint16/2-examples"},{"type":"function","title":"BitConverter.decode_uint32/2","doc":"Converts a binary representing a 32-bit unsigned integer into an integer.\nA 32-bit unsigned integer ranges from 0 to 4,294,967,295.\nRaises a `FunctionClauseError` if the binary doesn't have exactly 4 bytes.","ref":"BitConverter.html#decode_uint32/2"},{"type":"function","title":"Parameters - BitConverter.decode_uint32/2","doc":"- `binary`: A binary pattern that matches a 32-bit unsigned integer.\n\n  - `opts` (Keyword list, optional): Additional options.\n    - `:endianness` (atom): `:little` for little-endian or `:big` for big-endian. Defaults to `:little`.","ref":"BitConverter.html#decode_uint32/2-parameters"},{"type":"function","title":"Examples - BitConverter.decode_uint32/2","doc":"iex> BitConverter.decode_uint32(<<0, 0, 0, 0>>)\n    0\n\n    iex> BitConverter.decode_uint32(<<1, 0, 0 , 0>>)\n    1\n\n    iex> BitConverter.decode_uint32(<<10, 0, 0, 0>>)\n    10\n\n    iex> BitConverter.decode_uint32(<<255, 255, 255, 255>>)\n    4_294_967_295\n\n    iex> BitConverter.decode_uint32(<<1, 0, 0, 0>>, endianess: :big)\n    16_777_216\n\n    iex> BitConverter.decode_uint32(<<10, 0, 0, 0>>, endianess: :big)\n    167_772_160\n\n    iex> BitConverter.decode_uint32(<<255, 255, 255, 255>>, endianess: :big)\n    4_294_967_295\n\n    iex> BitConverter.decode_uint32(<<1, 0, 0, 0, 0>>)\n    ** (FunctionClauseError) no function clause matching in BitConverter.decode_uint32/2","ref":"BitConverter.html#decode_uint32/2-examples"},{"type":"function","title":"BitConverter.encode_int16/2","doc":"Converts an integer into a binary representing a 16-bit signed integer.\nA 16-bit signed integer ranges from -32,768 to 32,767.\nRaises a `FunctionClauseError` if the number is outside the valid range.","ref":"BitConverter.html#encode_int16/2"},{"type":"function","title":"Parameters - BitConverter.encode_int16/2","doc":"- `number`: An integer that fits in a 16-bit signed integer.\n\n  - `opts` (Keyword list, optional): Additional options.\n    - `:endianness` (atom): `:little` for little-endian or `:big` for big-endian. Defaults to `:little`.","ref":"BitConverter.html#encode_int16/2-parameters"},{"type":"function","title":"Examples - BitConverter.encode_int16/2","doc":"iex> BitConverter.encode_int16(1)\n    <<1, 0>>\n\n    iex> BitConverter.encode_int16(-32_768)\n    <<0, 128>>\n\n    iex> BitConverter.encode_int16(32_767)\n    <<255, 127>>\n\n    iex> BitConverter.encode_int16(256, endianess: :big)\n    <<1, 0>>\n\n    iex> BitConverter.encode_int16(1, endianess: :big)\n    <<0, 1>>\n\n    iex> BitConverter.encode_int16(32_768)\n    ** (FunctionClauseError) no function clause matching in BitConverter.encode_int16/2\n\n    iex> BitConverter.encode_int16(-32_769)\n    ** (FunctionClauseError) no function clause matching in BitConverter.encode_int16/2","ref":"BitConverter.html#encode_int16/2-examples"},{"type":"function","title":"BitConverter.encode_int32/2","doc":"Converts an integer into a binary representing a 32-bit signed integer.\nA 32-bit signed integer ranges from -2,147,483,648 to 2,147,483,647.\nRaises a `FunctionClauseError` if the number is outside the valid range.","ref":"BitConverter.html#encode_int32/2"},{"type":"function","title":"Parameters - BitConverter.encode_int32/2","doc":"- `number`: An integer that fits in a 32-bit signed integer.\n\n  - `opts` (Keyword list, optional): Additional options.\n    - `:endianness` (atom): `:little` for little-endian or `:big` for big-endian. Defaults to `:little`.","ref":"BitConverter.html#encode_int32/2-parameters"},{"type":"function","title":"Examples - BitConverter.encode_int32/2","doc":"iex> BitConverter.encode_int32(1)\n    <<1, 0, 0, 0>>\n\n    iex> BitConverter.encode_int32(-2_147_483_648)\n    <<0, 0, 0, 128>>\n\n    iex> BitConverter.encode_int32(2_147_483_647)\n    <<255, 255, 255, 127>>\n\n    iex> BitConverter.encode_int32(16_777_216, endianess: :big)\n    <<1, 0, 0, 0>>\n\n    iex> BitConverter.encode_int32(1, endianess: :big)\n    <<0, 0, 0, 1>>\n\n    iex> BitConverter.encode_int32(2_147_483_648)\n    ** (FunctionClauseError) no function clause matching in BitConverter.encode_int32/2\n\n    iex> BitConverter.encode_int32(-2_147_483_649)\n    ** (FunctionClauseError) no function clause matching in BitConverter.encode_int32/2","ref":"BitConverter.html#encode_int32/2-examples"},{"type":"function","title":"BitConverter.encode_uint16/2","doc":"Converts an integer into a binary representing a 16-bit unsigned integer.\nA 16-bit unsigned integer ranges from 0 to 65,535.\nRaises a `FunctionClauseError` if the number is outside the valid range.","ref":"BitConverter.html#encode_uint16/2"},{"type":"function","title":"Parameters - BitConverter.encode_uint16/2","doc":"- `number`: An integer that fits in a 16-bit unsigned integer.\n\n  - `opts` (Keyword list, optional): Additional options.\n    - `:endianness` (atom): `:little` for little-endian or `:big` for big-endian. Defaults to `:little`.","ref":"BitConverter.html#encode_uint16/2-parameters"},{"type":"function","title":"Examples - BitConverter.encode_uint16/2","doc":"iex> BitConverter.encode_uint16(1)\n    <<1, 0>>\n\n    iex> BitConverter.encode_uint16(65535)\n    <<255, 255>>\n\n    iex> BitConverter.encode_uint16(256, endianess: :big)\n    <<1, 0>>\n\n    iex> BitConverter.encode_uint16(65536)\n    ** (FunctionClauseError) no function clause matching in BitConverter.encode_uint16/2\n\n    iex> BitConverter.encode_uint16(-1)\n    ** (FunctionClauseError) no function clause matching in BitConverter.encode_uint16/2","ref":"BitConverter.html#encode_uint16/2-examples"},{"type":"function","title":"BitConverter.encode_uint32/2","doc":"Converts an integer into a binary representing a 32-bit unsigned integer.\nA 32-bit unsigned integer ranges from 0 to 4,294,967,295.\nRaises a `FunctionClauseError` if the number is outside the valid range.","ref":"BitConverter.html#encode_uint32/2"},{"type":"function","title":"Parameters - BitConverter.encode_uint32/2","doc":"- `number`: An integer that fits in a 32-bit unsigned integer.\n\n  - `opts` (Keyword list, optional): Additional options.\n    - `:endianness` (atom): `:little` for little-endian or `:big` for big-endian. Defaults to `:little`.","ref":"BitConverter.html#encode_uint32/2-parameters"},{"type":"function","title":"Examples - BitConverter.encode_uint32/2","doc":"iex> BitConverter.encode_uint32(1)\n    <<1, 0, 0, 0>>\n\n    iex> BitConverter.encode_uint32(4_294_967_295)\n    <<255, 255, 255, 255>>\n\n    iex> BitConverter.encode_uint32(16_777_216, endianess: :big)\n    <<1, 0, 0, 0>>\n\n    iex> BitConverter.encode_uint32(4_294_967_296)\n    ** (FunctionClauseError) no function clause matching in BitConverter.encode_uint32/2\n\n    iex> BitConverter.encode_uint32(-1)\n    ** (FunctionClauseError) no function clause matching in BitConverter.encode_uint32/2","ref":"BitConverter.html#encode_uint32/2-examples"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}